import type { Metadata } from "next";
import localFont from "next/font/local";
import "./globals.css";

import { cookies } from 'next/headers'
import { NavigationBar } from "@/components/ui/navigation-bar"
import { decryptToken } from '@/lib/jwt'


const geistSans = localFont({
  src: "./fonts/GeistVF.woff",
  variable: "--font-geist-sans",
  weight: "100 900",
});
const geistMono = localFont({
  src: "./fonts/GeistMonoVF.woff",
  variable: "--font-geist-mono",
  weight: "100 900",
});

export const metadata: Metadata = {
  title: "Brawl Set",
  description: "Un mode de jeu MTG 100% rennais",
};

export default async function RootLayout({
  children,
}: Readonly<{
  children: React.ReactNode;
}>) {
  const cookieStore = await cookies()
  const JWT = cookieStore.get("JWT")
  let username = ""
  if(JWT !== undefined){
    username = decryptToken(JWT.value)?.username
  }

  return (
    <html lang="fr">
      <body
        className={`${geistSans.variable} ${geistMono.variable} antialiased`}
      >
        <NavigationBar username={username} isLoggedIn={JWT !== undefined} />
        {children}
      </body>
    </html>
  );
}
